@@ -1,11 +1,11 @@
 package Catalyst::Component::Implicit;
-use base qw/Catalyst::Component/;
+
+use parent qw(Catalyst::Component);
 
 use Catalyst::Utils;
 
 sub COMPONENT {
-    my ($self, $c, $arguments) = @_;
-    my $class = ref $self || $self;
+    my ($self, $c, $arguments) = @_; my $class = ref $self || $self;
 
     # Inject an inner package intoto the subclass
     { no strict 'refs'; @{"$class\::Sub::ISA"} = @{"$class\::ISA"} }
@@ -13,4 +13,4 @@ sub COMPONENT {
     return $self->NEXT::COMPONENT( $c, $arguments );
 }
 
-1;
\ No newline at end of file
+1;
